Module package

Module package 

Package path resolution for config composition

Handles the @package directive and package path computation for config composition.

Structs

PackageResolver
Package resolution context

Functions

compute_target_path
Compute the target path for a config value given package and key path
join_path
Join path components
parse_package_header
Parse @package directive from config header
split_path
Split a target path into components